@@ -38,10 +38,14 @@ UncertaintyQuantificationToolbox is the collection of tools for Uncertainty Quan
 @copyright: 2012-2014 The Technical University of Denmark
 """
 
+import aux
+from aux import *
 import unittests
 from unittests import *
 
-__all__ = ["RandomSampling","ModelReduction","gPC","sobol_lib","CutANOVA","mcmc"]
+__all__ = []
+__all__ += aux.__all__
+__all__ += ["RandomSampling","ModelReduction","gPC","sobol_lib","CutANOVA","mcmc"]
 
 __author__ = "Daniele Bigoni"
 __copyright__ = """Copyright 2012-2014, The Technical University of Denmark"""
