@@ -45,19 +45,19 @@ def gPC_MultiIndex(dist,poly,distPoly,N,NI=[],quadTypes=None,left=None,right=Non
     gPC_MultiIndex(dist,poly,distPoly,N)
     Generates the Multi Index basis Vandermonde matrix using the list of 
     distributions of the parameters space approximated by the selected polynomials.
-    INPUT:
-        ``dist``: list of n distributions representing the n-Dimensional random space
-        ``poly``: list of n polynomials (class Spectral1D) used for approximating each
-            of the directions in the random space
-        ``distPoly``: list of n standard distributions associated to the polynomial selected
-        ``N``: maximum polynomial order in the basis
-        ``NI``: (int) number of points in which to evaluate the basis functions for precise cubature rules (if NI=[], the interpolated vandermonde is not evaluated)
-        ``quadTypes``: (list, ``Spectral1D.AVAIL_POINTS``) list of n types of quadrature points among Gauss, Gauss-Lobatto and Gauss-Radau. If ``None``, Gauss quadrature points are used.
-        ``left``: (list,float) list of left values used by ORTHPOL for Gauss-Lobatto rules (the dimensions where the value is not used can be set to anything)
-        ``right``: (list,float) list of left values used by ORTHPOL for Gauss-Lobatto rules (the dimensions where the value is not used can be set to anything)
-        ``end``: (list,float) list of left values used by ORTHPOL for Gauss-Radau rules (the dimensions where the value is not used can be set to anything)
-        ``warnings``: True if you want to read warning on memory allocation
-    OUTPUT: dictionary with the following attributes
+
+    :param dist: list of n distributions representing the n-Dimensional random space
+    :param poly: list of n polynomials (class Spectral1D) used for approximating each of the directions in the random space
+    :param distPoly: list of n standard distributions associated to the polynomial selected
+    :param N: maximum polynomial order in the basis
+    :param NI: (int) number of points in which to evaluate the basis functions for precise cubature rules (if NI=[], the interpolated vandermonde is not evaluated)
+    :param quadTypes: (list, ``Spectral1D.AVAIL_POINTS``) list of n types of quadrature points among Gauss, Gauss-Lobatto and Gauss-Radau. If ``None``, Gauss quadrature points are used.
+    :param left: (list,float) list of left values used by ORTHPOL for Gauss-Lobatto rules (the dimensions where the value is not used can be set to anything)
+    :param right: (list,float) list of left values used by ORTHPOL for Gauss-Lobatto rules (the dimensions where the value is not used can be set to anything)
+    :param end: (list,float) list of left values used by ORTHPOL for Gauss-Radau rules (the dimensions where the value is not used can be set to anything)
+    :param warnings: True if you want to read warning on memory allocation
+    
+    :returns: dictionary with the following attributes
         ``x``: tensor product of collocation points in the standard distributions
         ``w``: tensor product of the weights for cubature/projection rules (sum to 1 or prod(gamma0) respectively)
         ``vals``: tensor product of collocation points
@@ -127,14 +127,14 @@ def PCM_Tensor(dist,poly,distPoly,Ns,allocBasis=True):
     PCM_Tensor(dist,poly,distPoly,N)
     Generates the full tensor grid using the list of distributions of the parameters
     space approximated by the selected polynomials.
-    INPUT:
-        dist: list of n distributions representing the n-Dimensional random space
-        poly: list of n polynomials (class Spectral1D) used for approximating each
-            of the directions in the random space
-        distPoly: list of n standard distributions associated to the polynomial selected
-        Ns: list of n integers for the order of polynomial expansion in each direction
-        allocBasis: boolean. True if you want the tensor basis.
-    OUTPUT: dictionary with the following attributes
+
+    :param dist: list of n distributions representing the n-Dimensional random space
+    :param poly: list of n polynomials (class Spectral1D) used for approximating each of the directions in the random space
+    :param distPoly: list of n standard distributions associated to the polynomial selected
+    :param Ns: list of n integers for the order of polynomial expansion in each direction
+    :param allocBasis: boolean. True if you want the tensor basis.
+    
+    :returns: dictionary with the following attributes
         'x': tensor product of collocation points in the standard distributions
         'w': tensor product of the weights for cubature/projection rules (sum to 1 or prod(gamma0) respectively)
         'vals': tensor product of collocation points
@@ -236,7 +236,7 @@ def UQ_PCM_Tensor(solve,params,solvePostProcessing,dists,paramUpdate,polys,dists
         sols.append(sol)
         return sols
         
-    solutions = Experiments(solve,vals,params,paramUpdate,action)
+    solutions = run_experiments(solve,vals,params,paramUpdate,action)
     
     if myrank == 0:
         solutions = solvePostProcessing(solutions)    
@@ -381,7 +381,7 @@ def UQ_SparseGrid(solve,params,solvePostProcessing,dists,paramUpdate,method,k,sy
         sols.append(sol)
         return sols
         
-    solutions = Experiments(solve,vals,params,paramUpdate,action)
+    solutions = run_experiments(solve,vals,params,paramUpdate,action)
     
     if myrank == 0:
         solutions = solvePostProcessing(solutions)    
@@ -1053,7 +1053,7 @@ def UQ_MEPCM_Tensor(domain,solve,params,solvePostProcessing,paramUpdate,refOrder
         totComputations += vals.shape[0];
         
         # Run the experiments
-        sols = Experiments(solve, vals, params, paramUpdate, action);
+        sols = run_experiments(solve, vals, params, paramUpdate, action);
         
         if myrank == 0:
             # Split solutions by element
