@@ -22,14 +22,25 @@
 # Author: Daniele Bigoni
 #
 
-__all__ = ['RunUnitTests']
+__all__ = ['RunUnitTests','RunTestKL1D','RunTestKL2D','RunTestRandomSampling']
 
-def RunUnitTests(maxprocs=None):
+def RunTestRandomSampling(maxprocs=None,PLOTTING=False):
+    import TestRandomSampling
+    TestRandomSampling.run(maxprocs)
+
+def RunTestKL1D(maxprocs=None,PLOTTING=False):
+    import TestKL1D
+    TestKL1D.run(maxprocs,PLOTTING)
+
+def RunTestKL2D(maxprocs=None,PLOTTING=False):
+    import TestKL2D
+    TestKL2D.run(maxprocs,PLOTTING)
+
+def RunUnitTests(maxprocs=None,PLOTTING=False):
     """ Runs all the unit tests.
     
     :params int maxprocs: If MPI support is enabled, defines how many processors to use.
     """
-    import TestKL1D, TestKL2D
-    PLOTTING = False
-    TestKL1D.run(maxprocs,PLOTTING)
-    TestKL2D.run(maxprocs,PLOTTING)
+    RunTestRandomSampling(maxprocs,PLOTTING)
+    RunTestKL1D(maxprocs,PLOTTING)
+    RunTestKL2D(maxprocs,PLOTTING)
